@@ -1,11 +1,12 @@
+import getm
 import requests
-from io import BytesIO
 
 from .basefile import BaseAnVILFile
 
 
 class HypertextAnVILFile(BaseAnVILFile):
     def __init__(self, url, name=None, size=None, last_modified=None):
+        print(f"hypertext URL received: {url}")
         self.url = url
         if not name:
             self.name = url.split("/")[-1]
@@ -21,7 +22,7 @@ class HypertextAnVILFile(BaseAnVILFile):
                 self.last_modified = ""
 
     def get_bytes_handler(self):
-        return BytesIO(requests.get(self.url).content)
+        return getm.urlopen(self.url)
 
     @classmethod
     def factory(cls, urllist):
